==> haskell-bytestring-show-0.3.5.6-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-show
version:              0.3.5.6
visibility:           public
id:                   bytestring-show-0.3.5.6-354F2etVtLm8LclHePEmy
key:                  bytestring-show-0.3.5.6-354F2etVtLm8LclHePEmy
license:              BSD-3-Clause
maintainer:           Dan Doel <dan.doel@gmail.com>
author:               Dan Doel
homepage:             http://code.haskell.org/~dolio/
synopsis:             Efficient conversion of values into readable byte strings.
description:          Efficient conversion of values into readable byte strings.
category:             Text
abi:                  1fed6431fccf39b49a664e288e7e0f3b
exposed:              True
exposed-modules:      Text.Show.ByteString
hidden-modules:
    Text.Show.ByteString.Util Text.Show.ByteString.Char
    Text.Show.ByteString.Int Text.Show.ByteString.Float
    Text.Show.ByteString.Integer

import-dirs:          /usr/lib/ghc-8.8.3/site-local/bytestring-show-0.3.5.6
library-dirs:         /usr/lib/ghc-8.8.3/site-local/bytestring-show-0.3.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/bytestring-show-0.3.5.6
hs-libraries:         HSbytestring-show-0.3.5.6-354F2etVtLm8LclHePEmy
depends:
    array-0.5.4.0 base-4.13.0.0 binary-0.8.7.0 bytestring-0.10.10.0
    containers-0.6.2.1 integer-gmp-1.0.2.0

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-show/html/bytestring-show.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-show-0.3.5.6-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-show
version:              0.3.5.6
visibility:           public
id:                   bytestring-show-0.3.5.6-94v3ytksN1fGCzSI67FlZk
key:                  bytestring-show-0.3.5.6-94v3ytksN1fGCzSI67FlZk
license:              BSD-3-Clause
maintainer:           Dan Doel <dan.doel@gmail.com>
author:               Dan Doel
homepage:             http://code.haskell.org/~dolio/
synopsis:             Efficient conversion of values into readable byte strings.
description:          Efficient conversion of values into readable byte strings.
category:             Text
abi:                  70d88648e0f743e5e20445943df4db4d
exposed:              True
exposed-modules:      Text.Show.ByteString
hidden-modules:
    Text.Show.ByteString.Util Text.Show.ByteString.Char
    Text.Show.ByteString.Int Text.Show.ByteString.Float
    Text.Show.ByteString.Integer

import-dirs:          /usr/lib/ghc-8.10.1/site-local/bytestring-show-0.3.5.6
library-dirs:         /usr/lib/ghc-8.10.1/site-local/bytestring-show-0.3.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/bytestring-show-0.3.5.6
hs-libraries:         HSbytestring-show-0.3.5.6-94v3ytksN1fGCzSI67FlZk
depends:
    array-0.5.4.0 base-4.14.0.0 binary-0.8.8.0 bytestring-0.10.10.0
    containers-0.6.2.1 integer-gmp-1.0.3.0

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-show/html/bytestring-show.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
